@@ -22,12 +22,6 @@
     .extract_assembly_name_from_ftp_file_prefix(ftp_dir[2])
 }
 
-.make_pkgname_for_NCBI_datapkg <- function(abbr_organism, assembly_name)
-{
-    part4 <- gsub("[^0-9a-zA-Z.]", "", assembly_name)
-    paste0("BSgenome.", abbr_organism, ".NCBI.", part4)
-}
-
 .make_pkgtitle_for_NCBI_datapkg <- function(organism, assembly_name)
 {
     paste0("Full genomic sequences for ", organism,
@@ -113,8 +107,7 @@ forgeBSgenomeDataPkgFromNCBI <- function(assembly_accession,
                                          circ_seqs=NULL,
                                          destdir=".")
 {
-    if (!isSingleString(pkg_maintainer) || pkg_maintainer == "")
-        stop(wmsg("'pkg_maintainer' must be a single (non-empty) string"))
+    check_pkg_maintainer(pkg_maintainer)
     if (identical(pkg_author, NA)) {
         pkg_author <- pkg_maintainer
     } else if (!isSingleString(pkg_author) || pkg_author == "") {
@@ -165,34 +158,28 @@ forgeBSgenomeDataPkgFromNCBI <- function(assembly_accession,
     fastaTo2bit(fasta_file, sorted_twobit_file, assembly_accession)
 
     abbr_organism <- abbreviate_organism_name(organism)
-    pkgname <- .make_pkgname_for_NCBI_datapkg(abbr_organism, assembly_name)
-    pkgtitle <- .make_pkgtitle_for_NCBI_datapkg(organism, assembly_name)
-    pkgdesc <- .make_pkgdesc_for_NCBI_datapkg(organism, assembly_name,
-                                              assembly_accession)
-    check_pkg_maintainer(pkg_maintainer)
+    pkgname <- make_pkgname(abbr_organism, "NCBI", assembly_name)
+    pkg_title <- .make_pkgtitle_for_NCBI_datapkg(organism, assembly_name)
+    pkg_desc <- .make_pkgdesc_for_NCBI_datapkg(organism, assembly_name,
+                                               assembly_accession)
     biocview <- organism2biocview(organism)
-    seqnames <- build_Rexpr_as_string(seqnames)
-    circ_seqs <- build_Rexpr_as_string(circ_seqs)
+    forge_function <- "forgeBSgenomeDataPkgFromNCBI"
 
-    ## Create the package.
-    origdir <- system.file("pkgtemplates", "NCBI_BSgenome_datapkg",
-                           package="BSgenomeForge")
-    symValues <- list(BSGENOMEOBJNAME=abbr_organism,
-                      PKGTITLE=pkgtitle,
-                      PKGDESCRIPTION=pkgdesc,
-                      PKGVERSION=pkg_version,
-                      PKGAUTHOR=pkg_author,
-                      PKGMAINTAINER=pkg_maintainer,
-                      PKGLICENSE=pkg_license,
-                      ORGANISM=organism,
-                      GENOME=assembly_name,
-                      ORGANISMBIOCVIEW=biocview,
-                      SEQNAMES=seqnames,
-                      CIRCSEQS=circ_seqs)
-    pkg_dir <- createPackage(pkgname, destdir, origdir, symValues,
-                             unlink=TRUE, quiet=FALSE)[[1]]
-    move_file_to_datapkg(sorted_twobit_file, pkg_dir)
-
-    invisible(pkg_dir)
+    create_2bit_BSgenome_datapkg(sorted_twobit_file, pkgname,
+                                 BSgenome_objname=abbr_organism,
+                                 pkg_title=pkg_title,
+                                 pkg_desc=pkg_desc,
+                                 pkg_version=pkg_version,
+                                 pkg_author=pkg_author,
+                                 pkg_maintainer=pkg_maintainer,
+                                 pkg_license=pkg_license,
+                                 organism=organism,
+                                 provider="NCBI",
+                                 genome=assembly_name,
+                                 organism_biocview=biocview,
+                                 forge_function=forge_function,
+                                 circ_seqs=circ_seqs,
+                                 destdir=destdir,
+                                 move_twobit_file=TRUE)
 }
 
